@@ -32,13 +32,14 @@ enum : int {
     SBK_QQUICK3DGEOMETRY_ATTRIBUTE_SEMANTIC_IDX              = 4,
     SBK_QQUICK3DGEOMETRY_ATTRIBUTE_COMPONENTTYPE_IDX         = 3,
     SBK_QQUICK3DGEOMETRY_ATTRIBUTE_IDX                       = 2,
-    SBK_QQUICK3DINSTANCING_IDX                               = 6,
-    SBK_QQUICK3DINSTANCING_INSTANCETABLEENTRY_IDX            = 7,
-    SBK_QQUICK3DOBJECT_ITEMCHANGE_IDX                        = 9,
-    SBK_QQUICK3DOBJECT_IDX                                   = 8,
-    SBK_QQUICK3DTEXTUREDATA_FORMAT_IDX                       = 11,
-    SBK_QQUICK3DTEXTUREDATA_IDX                              = 10,
-    SBK_QtQuick3D_IDX_COUNT                                  = 12
+    SBK_QQUICK3DGEOMETRY_TARGETATTRIBUTE_IDX                 = 6,
+    SBK_QQUICK3DINSTANCING_IDX                               = 7,
+    SBK_QQUICK3DINSTANCING_INSTANCETABLEENTRY_IDX            = 8,
+    SBK_QQUICK3DOBJECT_ITEMCHANGE_IDX                        = 10,
+    SBK_QQUICK3DOBJECT_IDX                                   = 9,
+    SBK_QQUICK3DTEXTUREDATA_FORMAT_IDX                       = 12,
+    SBK_QQUICK3DTEXTUREDATA_IDX                              = 11,
+    SBK_QtQuick3D_IDX_COUNT                                  = 13
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtQuick3DTypes;
@@ -74,6 +75,7 @@ template<> inline PyTypeObject *SbkType< ::QQuick3DGeometry >() { return reinter
 template<> inline PyTypeObject *SbkType< ::QQuick3DGeometry::Attribute::Semantic >() { return SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DGEOMETRY_ATTRIBUTE_SEMANTIC_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQuick3DGeometry::Attribute::ComponentType >() { return SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DGEOMETRY_ATTRIBUTE_COMPONENTTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQuick3DGeometry::Attribute >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DGEOMETRY_ATTRIBUTE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QQuick3DGeometry::TargetAttribute >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DGEOMETRY_TARGETATTRIBUTE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuick3DInstancing >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DINSTANCING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuick3DInstancing::InstanceTableEntry >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DINSTANCING_INSTANCETABLEENTRY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuick3DObject::ItemChange >() { return SbkPySide6_QtQuick3DTypes[SBK_QQUICK3DOBJECT_ITEMCHANGE_IDX]; }
